@@ -96,7 +96,7 @@ def sample_hilbert_qplex(d, n_qplex_pts=10000, from_surface=True):
         R = np.array([displace(d, i, j) @ fiducial/np.sqrt(d) for j in range(d) for i in range(d)]).conj()
         return np.vstack([qplex_pts, np.array([abs(R @ rand_ket(d)[:,0])**2 for i in range(n_qplex_pts-d**2)])])
     else:
-        R = sic_povm(d)
+        R = Operators(sic_povm(d))
         return np.vstack([qplex_pts, np.array([R << rand_dm(d) for i in range(n_qplex_pts-d**2)])])
 
 ####################################################################################################
